Function shell_command_string_output

pub fn shell_command_string_output(
    command: impl Display,
    current_dir: impl Into<Path>,
) -> Result<(i32, String, String)>
Utility function to spawn a command from a string rather than array of arguments and returns strings for stdout and stderr rather than Vec<u8>. Stdout and Stderr are sanitized for memory safety during String conversion.

Returns a triple with (exit code, stdout, stderr)